<h1 align="center">Nomic</h1>
<p align="center">The Python client to the world's first neural database.</p>

<p align="center">
  <a href="https://docs.nomic.ai">Documentation</a> 
  <br> <br>
  <br> <br>
</p>

[//]: # (<img src="" alt="Nomic Workflow" style="display: block; margin: 0 auto;" />)
